:mod:`euphorie.client.layout`
==============================

.. automodule:: euphorie.client.layout


Views
-----

.. autoclass:: Shell

.. autoclass:: Layout

.. autoclass:: Includes

.. autoclass:: Tooltips

